@@ -1,7 +1,7 @@
 /* Copyright 2003 Roger Dingledine
- * Copyright 2004-2005 Roger Dingledine, Nick Mathewson */
+ * Copyright 2004-2006 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: torgzip.h,v 1.6 2005/04/01 20:15:54 nickm Exp $ */
+/* $Id: torgzip.h 5990 2006-02-12 23:44:02Z arma $ */
 
 /**
  * \file torgzip.h
@@ -10,7 +10,7 @@
 
 #ifndef __TORGZIP_H
 #define __TORGZIP_H
-#define TORGZIP_H_ID "$Id: torgzip.h,v 1.6 2005/04/01 20:15:54 nickm Exp $"
+#define TORGZIP_H_ID "$Id: torgzip.h 5990 2006-02-12 23:44:02Z arma $"
 
 typedef enum {
   GZIP_METHOD=1, ZLIB_METHOD=2, UNKNOWN_METHOD=3
@@ -23,10 +23,13 @@ tor_gzip_compress(char **out, size_t *out_len,
 int
 tor_gzip_uncompress(char **out, size_t *out_len,
                     const char *in, size_t in_len,
-                    compress_method_t method);
+                    compress_method_t method,
+                    int complete_only,
+                    int protocol_warn_level);
 
 int is_gzip_supported(void);
 
 int detect_compression_method(const char *in, size_t in_len);
 
 #endif
+
