@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: circuitbuild.c,v 1.230.2.8 2006/07/04 17:10:12 arma Exp $ */
+/* $Id: circuitbuild.c 6940 2006-07-30 04:38:48Z arma $ */
 const char circuitbuild_c_id[] =
-  "$Id: circuitbuild.c,v 1.230.2.8 2006/07/04 17:10:12 arma Exp $";
+  "$Id: circuitbuild.c 6940 2006-07-30 04:38:48Z arma $";
 
 /**
  * \file circuitbuild.c
@@ -182,7 +182,8 @@ circuit_rep_hist_note_result(circuit_t *circ)
   }
   if (server_mode(get_options())) {
     routerinfo_t *me = router_get_my_routerinfo();
-    tor_assert(me);
+    if (!me)
+      return;
     prev_digest = me->cache_info.identity_digest;
   }
   do {
@@ -682,10 +683,15 @@ circuit_extend(cell_t *cell, circuit_t *circ)
   char *id_digest=NULL;
 
   if (circ->n_conn) {
-    log_fn(LOG_PROTOCOL_WARN,LD_PROTOCOL,
+    log_fn(LOG_PROTOCOL_WARN, LD_PROTOCOL,
            "n_conn already set. Bug/attack. Closing.");
     return -1;
   }
+  if (!server_mode(get_options())) {
+    log_fn(LOG_PROTOCOL_WARN, LD_PROTOCOL,
+           "Got an extend cell, but running as a client. Closing.");
+    return -1;
+  }
 
   relay_header_unpack(&rh, cell->payload);
 
