@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: command.c,v 1.110 2006/03/05 09:50:25 nickm Exp $ */
+/* $Id: command.c 6940 2006-07-30 04:38:48Z arma $ */
 const char command_c_id[] =
-  "$Id: command.c,v 1.110 2006/03/05 09:50:25 nickm Exp $";
+  "$Id: command.c 6940 2006-07-30 04:38:48Z arma $";
 
 /**
  * \file command.c
@@ -172,6 +172,15 @@ command_process_create_cell(cell_t *cell, connection_t *conn)
                                END_CIRC_REASON_HIBERNATING);
     return;
   }
+  if (!server_mode(get_options())) {
+    log_fn(LOG_PROTOCOL_WARN, LD_PROTOCOL,
+           "Received create cell (type %d) from %s:%d, but we're a client. "
+           "Sending back a destroy.",
+           (int)cell->command, conn->address, conn->port);
+    connection_or_send_destroy(cell->circ_id, conn,
+                               END_CIRC_REASON_TORPROTOCOL);
+    return;
+  }
 
   /* If the high bit of the circuit ID is not as expected, then switch
    * which half of the space we'll use for our own CREATE cells.
