@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: connection_edge.c,v 1.393.2.4 2006/04/18 05:12:36 arma Exp $ */
+/* $Id: connection_edge.c 6940 2006-07-30 04:38:48Z arma $ */
 const char connection_edge_c_id[] =
-  "$Id: connection_edge.c,v 1.393.2.4 2006/04/18 05:12:36 arma Exp $";
+  "$Id: connection_edge.c 6940 2006-07-30 04:38:48Z arma $";
 
 /**
  * \file connection_edge.c
@@ -1575,12 +1575,20 @@ connection_exit_begin_conn(cell_t *cell, circuit_t *circ)
   uint16_t port;
 
   assert_circuit_ok(circ);
-  relay_header_unpack(&rh, cell->payload);
 
   /* XXX currently we don't send an end cell back if we drop the
    * begin because it's malformed.
    */
 
+  if (!server_mode(get_options()) &&
+      circ->purpose != CIRCUIT_PURPOSE_S_REND_JOINED) {
+    log_fn(LOG_PROTOCOL_WARN, LD_PROTOCOL,
+           "Relay begin cell at non-server. Dropping.");
+    return 0;
+  }
+
+  relay_header_unpack(&rh, cell->payload);
+
   if (!memchr(cell->payload+RELAY_HEADER_SIZE, 0, rh.length)) {
     log_warn(LD_PROTOCOL,"relay begin cell has no \\0. Dropping.");
     return 0;
