@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: dirserv.c,v 1.328 2006/04/10 01:35:56 nickm Exp $ */
+/* $Id: dirserv.c 6759 2006-07-14 03:17:49Z arma $ */
 const char dirserv_c_id[] =
-  "$Id: dirserv.c,v 1.328 2006/04/10 01:35:56 nickm Exp $";
+  "$Id: dirserv.c 6759 2006-07-14 03:17:49Z arma $";
 
 #include "or.h"
 
@@ -1193,7 +1193,10 @@ static uint32_t guard_bandwidth = 0;
 static INLINE int
 real_uptime(routerinfo_t *router, time_t now)
 {
-  return router->uptime + (now - router->cache_info.published_on);
+  if (now < router->cache_info.published_on)
+    return router->uptime;
+  else
+    return router->uptime + (now - router->cache_info.published_on);
 }
 
 /** Return 1 if <b>router</b> is not suitable for these parameters, else 0.
