@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: main.c,v 1.639.2.2 2006/04/25 07:31:16 arma Exp $ */
+/* $Id: main.c 6807 2006-07-22 07:25:27Z arma $ */
 const char main_c_id[] =
-  "$Id: main.c,v 1.639.2.2 2006/04/25 07:31:16 arma Exp $";
+  "$Id: main.c 6807 2006-07-22 07:25:27Z arma $";
 
 /**
  * \file main.c
@@ -601,7 +601,8 @@ directory_info_has_arrived(time_t now, int from_cache)
       !we_are_hibernating()) { /* connect to the appropriate routers */
     if (!authdir_mode(options))
       router_retry_connections(0, 1);
-    if (!from_cache && has_completed_circuit)
+    if (!from_cache &&
+        (has_completed_circuit || !any_predicted_circuits(now)))
       consider_testing_reachability();
   }
 }
@@ -864,7 +865,7 @@ run_scheduled_events(time_t now)
     /* also, check religiously for reachability, if it's within the first
      * 20 minutes of our uptime. */
     if (server_mode(options) &&
-        has_completed_circuit &&
+        (has_completed_circuit || !any_predicted_circuits(now)) &&
         stats_n_seconds_working < TIMEOUT_UNTIL_UNREACHABILITY_COMPLAINT &&
         !we_are_hibernating())
       consider_testing_reachability();
@@ -1055,7 +1056,6 @@ do_hup(void)
   or_options_t *options = get_options();
 
   log_notice(LD_GENERAL,"Received reload signal (hup). Reloading config.");
-  has_completed_circuit=0;
   if (accounting_is_enabled(options))
     accounting_record_bandwidth_usage(time(NULL));
 
